@@ -105,7 +105,7 @@ class GristleMetaData(object):
 
         #-------------------------------------------------------------------
         # This explicit connection was not initially needed - originally all
-        # work was performed through implicit connections.  But the need to 
+        # work was performed through implicit connections.  But the need to
         # run methods like:
         #    existing_views = engine.dialect.get_view_names(connect)
         # requires the explicit connection.
@@ -422,9 +422,9 @@ class FieldTools(simplesql.TableTools):
                                                 name='field_fk2',
                                                 ondelete='RESTRICT'),
                            CheckConstraint('field_len > 0',
-                                           name='field_len_ck1'),
-                           CheckConstraint("field_type in ('string','int','date','time','timestamp','float')",
-                                           name='field_len_ck2'),
+                                           name='field_ck1'),
+                           CheckConstraint("field_type in ('string','int','date','time','timestamp','float', 'unknown')",
+                                           name='field_ck2'),
                            CheckConstraint("( (element_name IS NULL AND field_type IS NOT NULL) \
                                            OR (element_name IS NOT NULL AND field_type IS NULL) ) ",
                                            name='field_ck3'),
@@ -439,8 +439,12 @@ class FieldTools(simplesql.TableTools):
         return self._table
 
 
-    def get_field_id(self, collection_id, field_order=None,
-                     field_name=None, field_type=None, field_len=None,
+    def get_field_id(self,
+                     collection_id,
+                     field_order=None,
+                     field_name=None,
+                     field_type=None,
+                     field_len=None,
                      field_desc=None):
         """Get field_id if one exists, ir not doesn't exist then create it.
            Return final id.
@@ -1191,4 +1195,3 @@ def create_view_rpt_field_analysis_v(engine, connection):
     if 'rpt_field_analysis_v' not in existing_views:
         create_sql = text(sql)
         _ = engine.execute(create_sql)
-
